pystardict [![Build Status](https://travis-ci.org/lig/pystardict.svg?branch=master)](https://travis-ci.org/lig/pystardict)
==========

Home page
---------

<https://github.com/lig/pystardict>

Authors
-------

Serge Matveenko <s@matveenko.ru> and contributors: <https://github.com/lig/pystardict/graphs/contributors>.

Installation
------------

```shell
pip install pystardict
```

How to use
----------

For working example look into `examples` directory at the `demo.py` file.
Examples are installed in the `/local/prefix/share/pystardict` directory, where
`/local/prefix` is your installation prefix.

How to contribute
-----------------

Fill free to report any bugs or send pull requests on Github: <https://github.com/lig/pystardict>.

Respect PEP8.
